import os
import pickle
import globalPluginHandler
import speechDictHandler
import time
import ui
import addonHandler


addonHandler.initTranslation()

#def _(argStr): return argStr #翻訳キャンセル

class GlobalPlugin(globalPluginHandler.GlobalPlugin):
	scriptCategory = _("Colab Speech")

	def __init__(self, *args, **kwargs):
		super(GlobalPlugin, self).__init__(*args, **kwargs)
		# ファイルの場所
		self.dictFile = os.path.join(os.path.realpath(os.path.dirname(os.path.dirname(__file__))), "colab.dic")
		self.configFile = os.path.join(os.path.realpath(os.path.dirname(os.path.dirname(__file__))), "config.dat")

		# 設定ファイル読み込み
		self.config = {"mode": False}
		try:
			if not os.path.isfile(self.configFile):
				with open(self.configFile, "wb") as f: pickle.dump(self.config, f)
			with open(self.configFile, "rb") as f: self.config = pickle.load(f)
		except: pass
		if "mode" in self.config and self.config["mode"]: self.load()

	def script_changeDict(self, gesture):
		if "colab" in speechDictHandler.dictTypes:
			self.clear()
		else:
			self.load()
	#Translators: Input help mode message for set synth command.
	script_changeDict.__doc__ = _("Colab Speechの適用状態を切り替える")

	def setConfig(self, key, val):
		self.config[key] = val
		try:
			with open(self.configFile, "wb") as f: pickle.dump(self.config, f)
		except:
			ui.message(_("設定を保存できませんでした。"))	

	
	def load(self):
		ui.message(_("Colab Speech有効。"))
		# 辞書オブジェクト作成
		speechDictHandler.dictionaries["colab"] = speechDictHandler.SpeechDict()
		speechDictHandler.dictionaries["colab"].load(self.dictFile)
		# colab辞書タイプを追加
		ls = list(speechDictHandler.dictTypes)
		ls.insert(0, "colab")
		speechDictHandler.dictTypes = tuple(ls)
		self.setConfig("mode", True)

	def clear(self):
		ui.message(_("Colab Speech無効。"))

		if "colab" in speechDictHandler.dictTypes:
			# colab辞書タイプを削除
			ls = list(speechDictHandler.dictTypes)
			del ls[ls.index("colab")]
			speechDictHandler.dictTypes = tuple(ls)
		if "colab" in speechDictHandler.dictionaries:
			del speechDictHandler.dictionaries["colab"]
		self.setConfig("mode", False)

	__gestures = {
		"kb:control+shift+NVDA+O": "changeDict"
	}
